@@ -1,10 +1,5 @@
 import cffi
-import os
-
-if os.name == "nt":
-    libcrypto = "libcrypto_static"
-else:
-    libcrypto = "crypto"
+from . import libcrypto
 
 ffi = cffi.FFI()
 ffi.cdef("""
@@ -29,5 +24,5 @@ void AES_cfb128_encrypt(const unsigned char *in, unsigned char *out,
 ffi.set_source(
     "snmp.openssl.aes",
     "#include <openssl/aes.h>",
-    libraries=[libcrypto]
+    libraries=[libcrypto],
 )
